[−][src]Struct scoped_spawn::remote_scope::RemoteScope
A scope for a child task.
Implementations
impl RemoteScope[src]
pub fn new() -> Self[src]
Constructs a new RemoteScope.
pub fn spawner(&mut self) -> RemoteSpawner[src]
Returns a spawner for the scoped child task.
It may be cheaper if this method is not called.
pub fn wrap<ParentCancelReceiver, ParentDoneSender, Fut, Done>(
self,
signal: ChildSignals<ParentCancelReceiver, ParentDoneSender>,
fut: Fut,
done: Done
) -> impl Future<Output = ()> where
ParentCancelReceiver: SignalReceiver,
ParentDoneSender: SignalSender,
Fut: Future<Output = ()>,
Done: FnOnce(), [src]
self,
signal: ChildSignals<ParentCancelReceiver, ParentDoneSender>,
fut: Fut,
done: Done
) -> impl Future<Output = ()> where
ParentCancelReceiver: SignalReceiver,
ParentDoneSender: SignalSender,
Fut: Future<Output = ()>,
Done: FnOnce(),
Wraps signal, fut, and done into a future suitable to be run in a new task.
The returned future will handle all signals for structured concurrency. It will also handle termination as described in the library overview.